import request from '@/config/axios'

// 工作经历 VO
export interface WorkExpVO {
  id: number // id
  userId: number // 用户id
  enterpriseId: number // 企业id
  enterpriseName: string // 企业名称（没有选择系统企业时可自定义）
  industryId: number // 所属行业
  deptName: string // 所属部门
  positionId: number // 所属职位
  positionName: string // 职位名称（没有选择系统职位时可自定义）
  startTime: Date // 在职开始日期
  endTime: Date // 在职结束时间
  content: string // 工作内容
  achievement: string // 业绩
  pay: number // 薪酬
  payType: number // 薪酬类型（0月薪 1年薪）
  currencyType: number // 货币类型
  skillList: string // 技能
}

// 工作经历 API
export const WorkExpApi = {
  // 查询工作经历分页
  getWorkExpPage: async (params: any) => {
    return await request.get({ url: `/menduner/system/work-exp/page`, params })
  },

  // 查询工作经历详情
  getWorkExp: async (id: number) => {
    return await request.get({ url: `/menduner/system/work-exp/get?id=` + id })
  },

  // 新增工作经历
  createWorkExp: async (data: WorkExpVO) => {
    return await request.post({ url: `/menduner/system/work-exp/create`, data })
  },

  // 修改工作经历
  updateWorkExp: async (data: WorkExpVO) => {
    return await request.put({ url: `/menduner/system/work-exp/update`, data })
  },

  // 删除工作经历
  deleteWorkExp: async (id: number) => {
    return await request.delete({ url: `/menduner/system/work-exp/delete?id=` + id })
  },

  // 导出工作经历 Excel
  exportWorkExp: async (params) => {
    return await request.download({ url: `/menduner/system/work-exp/export-excel`, params })
  }
}